class StreamType:
    live = 'live'
    event = 'event'
